bayespy.inference.vmp.nodes.gaussian.GaussianGammaISODistribution.random
========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISODistribution.random